@@ -26,6 +26,7 @@ VALID_SITE_CONTROL = (SITE_CONTROL_ALL,
                       SITE_CONTROL_MASTER_ONLY,
                       SITE_CONTROL_NONE)
 
+
 class Policy(object):
     """
     Wrapper object for creating and manipulating a Flash cross-domain
@@ -43,7 +44,7 @@ class Policy(object):
 
     Consult the documentation for the various methods of this class
     for more advanced uses.
-    
+
     """
     def __init__(self, *domains):
         self.site_control = None
@@ -68,15 +69,17 @@ class Policy(object):
         retrieved via HTTPS), pass ``secure=False``. Due to security
         concerns, it is strongly recommended that you not disable
         this.
-        
+
         """
-        self.domains[domain] = { 'to_ports': to_ports,
-                                 'secure': secure }
+        if self.site_control == SITE_CONTROL_NONE:
+            raise TypeError("Metapolicy currently forbids all access; to allow a domain, change the metapolicy.")
+        self.domains[domain] = {'to_ports': to_ports,
+                                'secure': secure}
 
     def metapolicy(self, permitted):
         """
-        Set meta-policy information (only applicable to master policy
-        files). Acceptable values correspond to those listed in
+        Set meta-policy to ``permitted``. (only applicable to master
+        policy files). Acceptable values correspond to those listed in
         Section 3(b)(i) of the crossdomain.xml specification, and are
         also available as a set of constants defined in this module.
 
@@ -84,10 +87,22 @@ class Policy(object):
         policies except socket policies, (which assume a default of
         ``all``) so if this is desired (and, for security, it
         typically is), this method does not need to be called.
-        
+
+        Note that a metapolicy of ``none`` forbids **all** access,
+        even if one or more domains have previously been specified as
+        allowed. As such, setting the metapolicy to ``none`` will
+        remove all access previously granted by ``allow_domain`` or
+        ``allow_headers``. Additionally, attempting to grant access
+        via ``allow_domain`` or ``allow_headers`` will, when the
+        metapolicy is ``none``, raise ``TypeError``.
+
         """
         if permitted not in VALID_SITE_CONTROL:
             raise TypeError('"%s" is not a valid value for the "permitted-cross-domain-policies" attribute of a site-control element' % permitted)
+        if permitted == SITE_CONTROL_NONE:
+            # Metapolicy 'none' means no access is permitted.
+            self.domains = {}
+            self.header_domains = {}
         self.site_control = permitted
 
     def allow_headers(self, domain, headers, secure=True):
@@ -100,17 +115,18 @@ class Policy(object):
         discouraged for security reasons.
 
         The value for ``headers`` should be a list of header names.
-        
+
         To disable Flash's requirement of security matching (e.g.,
         retrieving a policy via HTTPS will require that SWFs also be
         retrieved via HTTPS), pass ``secure=False``. Due to security
         concerns, it is strongly recommended that you not disable
         this.
-        
+
         """
-        
-        self.header_domains[domain] = { 'headers': headers,
-                                        'secure': secure }
+        if self.site_control == SITE_CONTROL_NONE:
+            raise TypeError("Metapolicy currently forbids all access; to allow headers from a domain, change the metapolicy.")
+        self.header_domains[domain] = {'headers': headers,
+                                       'secure': secure}
 
     def _get_xml_dom(self):
         """
@@ -121,7 +137,7 @@ class Policy(object):
         Note that the various elements appear inside the XML document
         in a specific order to ensure validity, so use caution when
         manipulating the returned ``Document``.
-        
+
         """
         policy_type = minidom.createDocumentType(qualifiedName='cross-domain-policy',
                                                  publicId=None,
